@@ -311,7 +311,8 @@ sub _build_dom
         unless $s->masterpage;
       
       confess $s->masterpage->virtual_path . " does not define an asp:ContentPlaceHolder '" . $attrs->{PlaceHolderID} . "'"
-        unless exists( $s->masterpage->{placeholders}->{ $attrs->{PlaceHolderID} } );
+        unless exists( $s->masterpage->{placeholders}->{ $attrs->{PlaceHolderID} } )
+          or $s->masterpage->can( $attrs->{PlaceHolderID} );
       
       while( my ( $chunk, $tagName, $prefix, $tag, $attrs, $contents2 ) =
         $contents =~ m{
